@@ -146,6 +146,7 @@
 #define HAVE_CUSERID 1
 #define HAVE_CXX_NEW 1
 /* #undef HAVE_DIRECTIO */
+#define HAVE_DLADDR 1
 #define HAVE_DLERROR 1
 #define HAVE_DLOPEN 1
 /* #undef HAVE_DOPRNT */
@@ -535,7 +536,11 @@
 /*
   MySQL features
 */
-#define ENABLED_LOCAL_INFILE 1
+#define LOCAL_INFILE_MODE_OFF  0
+#define LOCAL_INFILE_MODE_ON   1
+#define LOCAL_INFILE_MODE_AUTO 2
+#define ENABLED_LOCAL_INFILE LOCAL_INFILE_MODE_AUTO
+
 #define ENABLED_PROFILING 1
 /* #undef EXTRA_DEBUG */
 /* #undef BACKUP_TEST */
@@ -636,16 +641,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 32
+#define MYSQL_VERSION_PATCH 38
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.32"
+#define PACKAGE_STRING "MySQL Server 10.0.38"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.32"
-#define VERSION "10.0.32"
+#define PACKAGE_VERSION "10.0.38"
+#define VERSION "10.0.38"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "bundled jemalloc"
